@@ -25,15 +25,16 @@ use warnings;
 use autodie;
 
 use Moo;
+use namespace::clean;
 
-with('Lintian::Check');
+with 'Lintian::Check';
 
 sub files {
     my ($self, $file) = @_;
 
     # /usr/share/cmake-*
     if ($file->name =~ m,^usr/share/cmake-\d+\.\d+/.+,){
-        unless ($self->source eq 'cmake') {
+        unless ($self->processable->source eq 'cmake') {
             $self->tag('package-contains-cmake-private-file', $file->name);
         }
     }
